@@ -38,6 +38,7 @@ import java.util.List;
  * <tr><td class="TableSubHeadingColor"><b>Unit Tests:</b></td><td>GroupingListTest</td></tr>
  * <tr><td class="TableSubHeadingColor"><b>Issues:</b></td><td>
  *   <a href="https://glazedlists.dev.java.net/issues/show_bug.cgi?id=281">281</a>
+ *   <a href="https://glazedlists.dev.java.net/issues/show_bug.cgi?id=491">491</a>
  * </td></tr>
  * </table>
  *
@@ -202,16 +203,19 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
     }
 
     /** {@inheritDoc} */
+    @Override
     protected int getSourceIndex(int index) {
         return grouper.getBarcode().getIndex(index, Grouper.UNIQUE);
     }
 
     /** {@inheritDoc} */
+    @Override
     protected boolean isWritable() {
         return true;
     }
 
     /** {@inheritDoc} */
+    @Override
     public void listChanged(ListEvent<E> listChanges) {
         updates.beginEvent(true);
 
@@ -235,7 +239,7 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
 
             // insert all new groups (represented by the newly formed barcode)
             updates.addInsert(0, size() - 1);
-            
+
         } else {
             grouper.listChanged(listChanges);
         }
@@ -243,15 +247,17 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
     }
 
     /** {@inheritDoc} */
+    @Override
     public List<E> get(int index) {
         return groupLists.get(index).get();
     }
 
     /** {@inheritDoc} */
+    @Override
     public List<E> remove(int index) {
         if(index < 0 || index >= size()) throw new IndexOutOfBoundsException("Cannot remove at " + index + " on list of size " + size());
 
-        final List<E> removed = (List<E>) get(index);
+        final List<E> removed = get(index);
 
         // make a copy of the list to return
         final List<E> result = new ArrayList<E>(removed);
@@ -262,12 +268,13 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
     }
 
     /** {@inheritDoc} */
+    @Override
     public List<E> set(int index, List<E> value) {
         if(index < 0 || index >= size()) throw new IndexOutOfBoundsException("Cannot set at " + index + " on list of size " + size());
 
         updates.beginEvent(true);
 
-        final List<E> result = (List<E>) remove(index);
+        final List<E> result = remove(index);
         add(index, value);
 
         updates.commitEvent();
@@ -284,16 +291,19 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
      * <p><strong><font color="#FF0000">Warning:</font></strong> This method
      * breaks the contract required by {@link List#add(int, Object)}.
      */
+    @Override
     public void add(int index, List<E> value) {
         source.addAll(value);
     }
 
     /** {@inheritDoc} */
+    @Override
     public int size() {
         return grouper.getBarcode().colourSize(Grouper.UNIQUE);
     }
 
     /** {@inheritDoc} */
+    @Override
     public void dispose() {
         ((SortedList) source).dispose();
         super.dispose();
@@ -353,31 +363,37 @@ public final class GroupingList<E> extends TransformedList<E, List<E>> {
         }
 
         /** {@inheritDoc} */
+        @Override
         public E set(int index, E element) {
             return source.set(getSourceIndex(index), element);
         }
 
         /** {@inheritDoc} */
+        @Override
         public E get(int index) {
             return source.get(getSourceIndex(index));
         }
 
         /** {@inheritDoc} */
+        @Override
         public int size() {
             return getEndIndex() - getStartIndex();
         }
 
         /** {@inheritDoc} */
+        @Override
         public void clear() {
             source.subList(getStartIndex(), getEndIndex()).clear();
         }
 
         /** {@inheritDoc} */
+        @Override
         public E remove(int index) {
             return source.remove(getSourceIndex(index));
         }
 
         /** {@inheritDoc} */
+        @Override
         public void add(int index, E element) {
             source.add(getSourceIndex(index), element);
         }
