@@ -97,16 +97,19 @@ public class SeparatorList<E> extends TransformedList<E, E> {
     }
 
     /** {@inheritDoc} */
+    @Override
     public int size() {
         return collapsedElements.colourSize(Barcode.BLACK);
     }
 
     /** {@inheritDoc} */
+    @Override
     protected int getSourceIndex(int mutationIndex) {
         return collapsedElements.getIndex(mutationIndex, Barcode.BLACK);
     }
 
     /** {@inheritDoc} */
+    @Override
     protected boolean isWritable() {
         return true;
     }
@@ -174,6 +177,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
     }
 
     /** {@inheritDoc} */
+    @Override
     public void listChanged(ListEvent<E> listChanges) {
         updates.beginEvent(true);
 
@@ -380,6 +384,15 @@ public class SeparatorList<E> extends TransformedList<E, E> {
         }
     }
 
+    /** {@inheritDoc} */
+    @Override
+    public void dispose() {
+        // dispose internal SeparatorInjectorList and SortedList
+        separatorSource.dispose();
+        separatorSource.source.dispose();
+        super.dispose();
+    }
+
     /**
      * A separator heading the elements of a group.
      */
@@ -510,7 +523,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
                 insertedSeparators.add(groupIndex + sourceIndex, SEPARATOR, 1);
                 Element<GroupSeparator> node = separators.add(groupIndex, new GroupSeparator(), 1);
                 node.get().setNode(node);
-                node.get().setLimit(defaultLimit);
+                node.get().applyLimit(defaultLimit, false);
             }
             // update the cached values in all separators
             for(int i = 0; i < separators.size(); i++) {
@@ -519,6 +532,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
         }
 
         /** {@inheritDoc} */
+        @Override
         public E get(int index) {
             Object type = insertedSeparators.get(index);
             if(type == SEPARATOR) return (E)separators.get(getSeparatorIndex(index)).get();
@@ -527,6 +541,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
         }
 
         /** {@inheritDoc} */
+        @Override
         protected int getSourceIndex(int mutationIndex) {
             Object type = insertedSeparators.get(mutationIndex);
             if(type == SEPARATOR) throw new IllegalArgumentException("No source index exists for the separator located at index " + mutationIndex);
@@ -541,16 +556,19 @@ public class SeparatorList<E> extends TransformedList<E, E> {
         }
 
         /** {@inheritDoc} */
+        @Override
         protected boolean isWritable() {
             return true;
         }
 
         /** {@inheritDoc} */
+        @Override
         public int size() {
             return insertedSeparators.size();
         }
 
         /** {@inheritDoc} */
+        @Override
         public void listChanged(ListEvent<E> listChanges) {
             // when the separator comparator is changed in the source list, let
             // the grouper know so we can rebuild our groups, then bail since
@@ -692,7 +710,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
                 // If this fix poses a problem, we might want to change the way
                 // Grouper works to fire a special flag called 'shift' with the
                 // value true whenever the group joined is a RIGHT_GROUP
-                int shiftGroupIndex = groupIndex + 1;
+                final int shiftGroupIndex = groupIndex + 1;
                 if(groupChangeType == ListEvent.DELETE && elementChangeType != ListEvent.INSERT
                         && shiftGroupIndex < insertedSeparators.colourSize(SEPARATOR)
                         && shiftGroupIndex < grouper.getBarcode().colourSize(Grouper.UNIQUE)) {
@@ -708,6 +726,35 @@ public class SeparatorList<E> extends TransformedList<E, E> {
                         //System.out.println("Changed from " + was + " to " + now);
                     }
                 }
+                // handle separator shifts for source list changes like AACCC -> AAACC or AAACC
+                // -> AACCC:
+                // an element at the beginning or end of an existing group is changed such that
+                // it now should belong to the neighbour group, but the element doesn't change
+                // its position in the SortedList
+                // the grouper barcode adjusts correctly, but here we have to adjust the
+                // separator positions accordingly
+                if (groupChangeType == ListEvent.UPDATE && elementChangeType == ListEvent.UPDATE
+                        && shiftGroupIndex < insertedSeparators.colourSize(SEPARATOR)
+                        && shiftGroupIndex < grouper.getBarcode().colourSize(Grouper.UNIQUE)) {
+                    // when we have an element update and a group update we check and synchronize
+                    // the separator position of the next group with the help of the grouper barcode unique index
+                    int collapsedGroupStartIndex = grouper.getBarcode().getIndex(shiftGroupIndex, Grouper.UNIQUE);
+                    int separatorsIndex = insertedSeparators.getIndex(shiftGroupIndex , SEPARATOR);
+                    int calculatedSeparatorPos = collapsedGroupStartIndex + shiftGroupIndex;
+//                    String was = insertedSeparators.toString();
+                    if (calculatedSeparatorPos != separatorsIndex) {
+                        // the separator position does not match the grouper barcode -> adjust it
+                        insertedSeparators.remove(separatorsIndex, 1);
+                        updates.addDelete(separatorsIndex);
+                        insertedSeparators.add(calculatedSeparatorPos, SEPARATOR, 1);
+                        // for the update event we have to account for the previous delete
+                        final int insertPos = (calculatedSeparatorPos < separatorsIndex) ? calculatedSeparatorPos
+                                : calculatedSeparatorPos - 1;
+                        updates.addInsert(insertPos);
+//                        String now = insertedSeparators.toString();
+//                        System.out.println("Changed from " + was + " to " + now);
+                    }
+                }
             }
         }
 
@@ -729,27 +776,39 @@ public class SeparatorList<E> extends TransformedList<E, E> {
             public int getLimit() {
                 return limit;
             }
+
             /** {@inheritDoc} */
             public void setLimit(int limit) {
+                applyLimit(limit, true);
+            }
+
+            /**
+             * Applies the maximum number of elements in this group to show.
+             *
+             * @param limit the limit
+             * @param fireEvents flag to indicate if ListEvents should be fired or not
+             */
+            protected void applyLimit(int limit, boolean fireEvents) {
                 if(this.limit == limit) return;
                 // fail gracefully if the node is null, that means this separator
                 // has been removed from the list but its still visible to an editor
                 if(node == null) {
                     return;
                 }
-
                 this.limit = limit;
-
-                // notify the world of this separator change
-                updates.beginEvent();
-                int groupIndex = separators.indexOfNode(node, (byte)1);
-                int separatorIndex = insertedSeparators.getIndex(groupIndex, SEPARATOR);
-                updates.addUpdate(separatorIndex);
-                updates.commitEvent();
+                if (fireEvents) {
+                    // notify the world of this separator change
+                    updates.beginEvent();
+                    int groupIndex = separators.indexOfNode(node, (byte)1);
+                    int separatorIndex = insertedSeparators.getIndex(groupIndex, SEPARATOR);
+                    updates.addUpdate(separatorIndex);
+                    updates.commitEvent();
+                }
             }
+
             /** {@inheritDoc} */
             public List<E> getGroup() {
-                if(node == null) return Collections.EMPTY_LIST;
+                if(node == null) return Collections.emptyList();
                 return source.subList(start(), end());
             }
             /** {@inheritDoc} */
@@ -807,6 +866,7 @@ public class SeparatorList<E> extends TransformedList<E, E> {
             }
 
             /** {@inheritDoc} */
+            @Override
             public String toString() {
                 return "" + size() + " elements starting with \"" + first() + "\"";
             }
