@@ -22,7 +22,7 @@ public final class FalseMatcher<E> implements Matcher<E> {
 	 * Return a singleton instance.
 	 */
 	public static <E> Matcher<E> getInstance() {
-		return (Matcher<E>) INSTANCE;
+		return INSTANCE;
 	}
 
     /** {@inheritDoc} */
