@@ -21,7 +21,7 @@ public final class NotNullMatcher<E> implements Matcher<E> {
 	 * Return a singleton instance.
 	 */
 	public static <E> Matcher<E> getInstance() {
-		return (Matcher<E>) INSTANCE;
+		return INSTANCE;
 	}
 
     /** {@inheritDoc} */
@@ -30,7 +30,8 @@ public final class NotNullMatcher<E> implements Matcher<E> {
 	}
 
     /** {@inheritDoc} */
-	public String toString() {
+	@Override
+    public String toString() {
 		return "[NotNullMatcher]";
 	}
 }
\ No newline at end of file
