@@ -4,19 +4,11 @@
 package ca.odell.glazedlists.impl.pmap;
 
 // NIO is used for CTP
-import java.util.*;
-import java.nio.*;
-import java.nio.channels.*;
-import java.net.*;
-import java.io.*;
-// logging
-import java.util.logging.*;
-
 /**
  * This doesn't do anything! It's useful for flushing pending events with invokeAndWait().
  */
 class NoOp implements Runnable {
-    
+
     /** singleton */
     private static NoOp instance = new NoOp();
 
@@ -26,7 +18,7 @@ class NoOp implements Runnable {
     private NoOp() {
         // nothing
     }
-    
+
     /**
      * Get an instance of NoOp. This is used instead of a conventional constructor
      * because NoOp is a singleton.
@@ -34,7 +26,7 @@ class NoOp implements Runnable {
     public static NoOp instance() {
         return instance;
     }
-    
+
     /**
      * Doesn't do anything!
      */
