@@ -11,26 +11,32 @@ import ca.odell.glazedlists.gui.TableFormat;
 import ca.odell.glazedlists.impl.SortIconFactory;
 import ca.odell.glazedlists.impl.gui.SortingStrategy;
 
-import javax.swing.*;
-import javax.swing.plaf.UIResource;
-import javax.swing.event.TableModelEvent;
-import javax.swing.event.TableModelListener;
-import javax.swing.table.TableCellRenderer;
-import javax.swing.table.TableColumnModel;
-import javax.swing.table.DefaultTableCellRenderer;
-import java.awt.*;
+import java.awt.AWTEventMulticaster;
+import java.awt.Component;
+import java.awt.Cursor;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
-import java.util.Comparator;
-import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
+import java.util.Comparator;
+
+import javax.swing.Icon;
+import javax.swing.JLabel;
+import javax.swing.JTable;
+import javax.swing.SwingConstants;
+import javax.swing.event.TableModelEvent;
+import javax.swing.event.TableModelListener;
+import javax.swing.plaf.UIResource;
+import javax.swing.table.DefaultTableCellRenderer;
+import javax.swing.table.TableCellRenderer;
+import javax.swing.table.TableColumnModel;
 
 /**
- * A TableComparatorChooser is a tool that allows the user to sort a ListTable by clicking
+ * A TableComparatorChooser is a tool that allows the user to sort a table by clicking
  * on the table's headers. It requires that the {@link JTable}s model is an
- * {@link EventTableModel} with a {@link SortedList} as a source.
+ * {@link AdvancedTableModel} with a {@link SortedList} as a source.
  *
  * <p>This class includes custom arrow icons that indicate the sort
  * order. The icons used are chosen based on the current Swing look and feel.
@@ -47,7 +53,7 @@ import java.beans.PropertyChangeEvent;
  * clicks subsequent columns. The list is sorted by the first column and ties
  * are broken by the second column.
  *
- * <p>If the {@link EventTableModel} uses an {@link AdvancedTableFormat}, its
+ * <p>If the {@link AdvancedTableModel} uses an {@link AdvancedTableFormat}, its
  * {@link AdvancedTableFormat#getColumnComparator} method will be used to
  * populate the initial column {@link Comparator}s.
  *
@@ -102,7 +108,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
      * performed and fixes an API flaw by explicitly requiring the TableFormat.
      */
     public TableComparatorChooser(JTable table, SortedList<E> sortedList, Object strategy) {
-        this(table, sortedList,strategy,((EventTableModel<E>)table.getModel()).getTableFormat());
+        this(table, sortedList,strategy,((AdvancedTableModel<E>)table.getModel()).getTableFormat());
     }
 
     /**
@@ -161,8 +167,8 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
      * If at any time the table should no longer sort, the behaviour can be
      * removed calling {@link #dispose()} on the object returned by this method.
      *
-     * <p>This method assumes that the JTable is backed by an EventTableModel
-     * and it is from that EventTableModel that the TableFormat should be
+     * <p>This method assumes that the JTable is backed by an AdvancedTableModel
+     * and it is from that AdvancedTableModel that the TableFormat should be
      * extracted. This is, by far, the typical case and so we provide this
      * simpler install method for convenience.
      *
@@ -179,7 +185,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
      *      mouse clicks on the table header into sorting actions on the sortedList.
      */
     public static <E> TableComparatorChooser<E> install(JTable table, SortedList<E> sortedList, Object strategy) {
-        return install(table, sortedList, strategy, ((EventTableModel<E>)table.getModel()).getTableFormat());
+        return install(table, sortedList, strategy, ((AdvancedTableModel<E>)table.getModel()).getTableFormat());
     }
 
     /**
@@ -280,6 +286,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
      * <p>To do this, clicks are injected into each of the
      * corresponding <code>ColumnClickTracker</code>s.
      */
+    @Override
     protected void redetectComparator(Comparator<? super E> currentComparator) {
         super.redetectComparator(currentComparator);
 
@@ -291,6 +298,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
     /**
      * Updates the comparator in use and applies it to the table.
      */
+    @Override
     protected final void rebuildComparator() {
         super.rebuildComparator();
 
@@ -305,6 +313,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
     /**
      * Gets the sorting style currently applied to the specified column.
      */
+    @Override
     protected final int getSortingStyle(int column) {
         return super.getSortingStyle(table.convertColumnIndexToModel(column));
     }
@@ -356,10 +365,11 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
      * to be garbage collected before its source {@link EventList}. This is
      * necessary for situations where an {@link TableComparatorChooser} is short-lived but
      * its source {@link EventList} is long-lived.
-     * 
+     *
      * <p><strong><font color="#FF0000">Warning:</font></strong> It is an error
      * to call any method on a {@link TableComparatorChooser} after it has been disposed.
      */
+    @Override
     public void dispose() {
         super.dispose();
         headerClickHandler.dispose();
@@ -405,8 +415,8 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
          */
         public void propertyChange(PropertyChangeEvent evt) {
             // get the two EventTableModels
-            final EventTableModel<E> oldModel = evt.getOldValue() instanceof EventTableModel ? (EventTableModel<E>) evt.getOldValue() : null;
-            final EventTableModel<E> newModel = evt.getNewValue() instanceof EventTableModel ? (EventTableModel<E>) evt.getNewValue() : null;
+            final AdvancedTableModel<E> oldModel = evt.getOldValue() instanceof AdvancedTableModel ? (AdvancedTableModel<E>) evt.getOldValue() : null;
+            final AdvancedTableModel<E> newModel = evt.getNewValue() instanceof AdvancedTableModel ? (AdvancedTableModel<E>) evt.getNewValue() : null;
 
             // stop listening for TableModelEvents in the oldModel and start for the newModel, if possible
             if (oldModel != null) oldModel.removeTableModelListener(this);
@@ -425,10 +435,10 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
          */
         public void tableChanged(TableModelEvent event) {
             if(event.getFirstRow() == TableModelEvent.HEADER_ROW && event.getColumn() == TableModelEvent.ALL_COLUMNS) {
-                if (table.getModel() instanceof EventTableModel) {
+                if (table.getModel() instanceof AdvancedTableModel) {
                     // the table structure may have changed due to a change in the table format
                     // so we conservatively reset the TableFormat on this TableComparatorChooser
-                    setTableFormat(((EventTableModel<E>) table.getModel()).getTableFormat());
+                    setTableFormat(((AdvancedTableModel<E>) table.getModel()).getTableFormat());
                 }
             }
 
@@ -546,6 +556,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
             table.getTableHeader().addMouseListener(this);
         }
 
+        @Override
         public void mouseClicked(MouseEvent e) {
             // if the MouseEvent is popping up a context menu, do not sort
             if (mouseEventIsPerformingPopupTrigger) return;
@@ -574,6 +585,7 @@ public class TableComparatorChooser<E> extends AbstractTableComparatorChooser<E>
          * can avoid sorting the table when the poor user just wants to show
          * a context menu.
          */
+        @Override
         public void mousePressed(MouseEvent mouseEvent) {
             this.mouseEventIsPerformingPopupTrigger = mouseEvent.isPopupTrigger();
         }
